Getting Started
***************

This is the basic getting started section. It provides the basics on how the balder framework works. We recommend
to go through this section, before going deeper into the :ref:`Basic Guides<Basic Guides>` or
:ref:`Reference Guides<Reference Guides>`. The Getting Started part of the documentation helps to understand the key
concepts of balder in a short time. With it, you can directly start to write your own test scenarios or use one of the
available balderhub projects and create your own setups for it.

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    installation.rst
    what_is_rsbt.rst
    balder_components.rst
